pages Package
=============

:mod:`pages` Package
--------------------

.. automodule:: camelot.view.wizard.pages
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`backup_page` Module
-------------------------

.. automodule:: camelot.view.wizard.pages.backup_page
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`form_page` Module
-----------------------

.. automodule:: camelot.view.wizard.pages.form_page
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`progress_page` Module
---------------------------

.. automodule:: camelot.view.wizard.pages.progress_page
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`select` Module
--------------------

.. automodule:: camelot.view.wizard.pages.select
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`update_entities_page` Module
----------------------------------

.. automodule:: camelot.view.wizard.pages.update_entities_page
    :members:
    :undoc-members:
    :show-inheritance:

